anchorite documentation
=======================

.. image:: _static/anchorite.svg
   :width: 200px
   :alt:   anchorite hex sticker
   :align: center

Welcome to the documentation for `anchorite`.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   api
